hstrat.hstrat.stratum\_retention\_condemners.StratumRetentionCondemnerPerfectResolution
=======================================================================================

.. currentmodule:: hstrat.hstrat.stratum_retention_condemners

.. autoclass:: StratumRetentionCondemnerPerfectResolution

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~StratumRetentionCondemnerPerfectResolution.CalcMrcaUncertaintyUpperBound
      ~StratumRetentionCondemnerPerfectResolution.CalcNumStrataRetainedExact
      ~StratumRetentionCondemnerPerfectResolution.CalcNumStrataRetainedUpperBound
      ~StratumRetentionCondemnerPerfectResolution.CalcRankAtColumnIndex
      ~StratumRetentionCondemnerPerfectResolution.__init__
   
   

   
   
   